@@ -20,21 +20,20 @@ eval_broom <-  requireNamespace("broom", quietly = TRUE)
 if (eval_broom) library(broom)
 eval_broom_mixed <-  requireNamespace("broom.mixed", quietly = TRUE)
 if (eval_broom_mixed) library(broom.mixed)
+eval_gginnards <-  requireNamespace("gginnards", quietly = TRUE)
+if (eval_gginnards) library(gginnards)
 
 ## -----------------------------------------------------------------------------
 old_theme <- theme_set(theme_bw())
 
 ## -----------------------------------------------------------------------------
 set.seed(4321)
-# generate artificial data
-x <- 1:100
-y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
-my.data <- data.frame(x, 
-                      y, 
-                      group = c("A", "B"), 
-                      y2 = y * c(0.5,2),
-                      block = c("a", "a", "b", "b"),
-                      wt = sqrt(x))
+x <- (1:100) / 10
+y <- x + rnorm(length(x))
+my.data <- data.frame(x = x,
+                      y = y,
+                      y.desc = - y,
+                      group = c("A", "B"))
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
@@ -54,11 +53,7 @@ ggplot(my.data, aes(x, y, color = group)) +
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y, color = group)) +
   geom_point() +
-  stat_correlation(mapping = aes(label = paste(after_stat(cor.label),
-                                               after_stat(t.value.label),
-                                               after_stat(p.value.label),
-                                               after_stat(n.label),
-                                               sep = '*"; "*')))
+  stat_correlation(mapping = use_label(c("R", "t", "P", "n")))
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
@@ -69,7 +64,7 @@ ggplot(my.data, aes(x, y)) +
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
-  stat_correlation(mapping = aes(color = ifelse(after_stat(cor) > 0.9,
+  stat_correlation(mapping = aes(color = ifelse(after_stat(cor) > 0.955,
                                                 "red", "black"))) +
   scale_color_identity() +
   facet_wrap(~group)
@@ -79,10 +74,11 @@ set.seed(4321)
 # generate artificial data
 x <- 1:100
 y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
+y <- y / max(y)
 my.data <- data.frame(x, 
                       y, 
                       group = c("A", "B"), 
-                      y2 = y * c(0.5,2),
+                      y2 = y * c(1, 2) + c(0, 0.2),
                       block = c("a", "a", "b", "b"),
                       wt = sqrt(x))
 
@@ -98,26 +94,31 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)), formula = formula)
+  stat_poly_eq(mapping = use_label("eq"), formula = formula)
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(adj.rr.label)), formula = formula) +
-  stat_poly_eq(aes(label = after_stat(AIC.label)),
-               label.x = "right", label.y = "bottom", size = 3,     
+  stat_poly_eq(mapping = aes(label = after_stat(eq.label)), 
                formula = formula)
 
+## -----------------------------------------------------------------------------
+formula <- y ~ poly(x, 3, raw = TRUE)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  stat_poly_line(formula = formula) +
+  stat_poly_eq(mapping = use_label("adj.R2"), formula = formula) +
+  stat_poly_eq(mapping = use_label("AIC"), label.x = "right", label.y = "bottom", size = 3,
+               formula = formula)
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  paste(after_stat(eq.label), after_stat(adj.rr.label), 
-                                  sep = "*\", \"*")),
+  stat_poly_eq(mapping = use_label(c("eq", "adj.R2")),
                formula = formula) +
   labs(x = expression(italic(x)), y = expression(italic(y)))
 
@@ -138,8 +139,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  paste(after_stat(eq.label), after_stat(adj.rr.label), 
-                                  sep = "~~italic(\"with\")~~")),
+  stat_poly_eq(mapping = use_label(c("eq", "adj.R2"), sep = "~~italic(\"with\")~~"),
                formula = formula)
 
 ## ---- eval=eval_flag----------------------------------------------------------
@@ -155,7 +155,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = FALSE,
                formula = formula)
 
@@ -164,7 +164,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = "italic(hat(y))~`=`~",
                formula = formula)
 
@@ -173,7 +173,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)),
+  stat_poly_eq(mapping = use_label(c("eq", "R2")),
                eq.with.lhs = "italic(h)~`=`~",
                eq.x.rhs = "~italic(z)",
                formula = formula) +
@@ -184,7 +184,7 @@ formula <- y ~ poly(x, 2, raw = TRUE)
 ggplot(my.data, aes(x, log10(y + 1e6))) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = "plain(log)[10](italic(delta)+10^6)~`=`~",
                eq.x.rhs = "~Omega",
                formula = formula) +
@@ -195,7 +195,7 @@ formula <- y ~ poly(x, 5, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = after_stat(eq.label)), formula = formula)
+  stat_poly_eq(mapping = use_label("eq"), formula = formula)
 
 ## ---- eval=eval_flag----------------------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3) - 1
@@ -216,6 +216,26 @@ ggplot(my.data, aes(x, y)) +
                formula = formula) +
   labs(x = expression(italic(x)), y = expression(italic(y)))
 
+## -----------------------------------------------------------------------------
+poly_or_mean <- function(formula, data, ...) {
+   fm <- lm(formula = formula, data = data, ...)
+   if (anova(fm)[["Pr(>F)"]][1] > 0.1) {
+      lm(formula = y ~ 1, data = data, ...)
+   } else {
+      fm
+   }
+}
+
+## -----------------------------------------------------------------------------
+ggplot(mpg, aes(displ, hwy)) +
+   geom_point() +
+   stat_poly_line(method = "poly_or_mean") +
+   stat_poly_eq(method = poly_or_mean,
+   aes(label = after_stat(eq.label)),
+   label.x = "right") +
+   theme(legend.position = "bottom") +
+   facet_wrap(~class, ncol = 2)
+
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2)) +
@@ -294,31 +314,31 @@ ggplot(my.data, aes(x, y2, colour = group)) +
   geom_point() +
   stat_poly_line(formula = formula) +
   stat_poly_eq(geom = "text", aes(label = after_stat(eq.label)),
-               label.x = c(100, 90), label.y = c(-1e4, 2.1e6), hjust = "inward",
+               label.x = c(100, 20), label.y = c(-0.1, 2.1), hjust = "inward",
                formula = formula)
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = y ~ x, color = "blue") +
-  stat_poly_eq(aes(label = after_stat(eq.label)), color = "blue") +
+  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
   stat_poly_line(formula = y ~ x, color = "red", orientation = "y") +
-  stat_poly_eq(aes(label = after_stat(eq.label)), color = "red", orientation = "y",
+  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
                label.y = 0.9)
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_ma_line() +
-  stat_ma_eq(aes(label = after_stat(eq.label)))
+  stat_ma_eq(mapping = use_label("eq"))
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_ma_line(color = "blue") +
-  stat_ma_eq(aes(label = after_stat(eq.label)), color = "blue") +
+  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
   stat_ma_line(color = "red", orientation = "y") +
-  stat_ma_eq(aes(label = after_stat(eq.label)), color = "red", orientation = "y",
+  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
              label.y = 0.9)
 
 ## ---- warning=FALSE-----------------------------------------------------------
@@ -329,7 +349,7 @@ ggplot(my.data, aes(x, y)) +
 ## ---- warning=FALSE-----------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
-  stat_quant_line(formula = y ~ poly(x, 2), quantiles = c(0.1, 0.9))
+  stat_quant_line(formula = y ~ poly(x, 2), quantiles = c(0.05, 0.95))
 
 ## ---- warning=FALSE-----------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
@@ -357,7 +377,7 @@ ggplot(my.data, aes(x, y, color = group)) +
 ggplot(my.data, aes(x, y, group = group, linetype = group, 
                     shape = group, grp.label = group)) +
   geom_point() +
-  stat_quantile(formula = formula, color = "black") +
+  stat_quant_line(formula = formula, quantiles = c(0.05, 0.95), color = "black") +
   stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
                                   after_stat(eq.label), sep = "")),
                 formula = formula, quantiles = c(0.05, 0.95)) +
@@ -367,10 +387,10 @@ ggplot(my.data, aes(x, y, group = group, linetype = group,
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_quant_line(formula = y ~ x, color = "blue", quantiles = 0.05) +
-  stat_quant_eq(aes(label = after_stat(eq.label)), formula = y ~ x, color = "blue",
+  stat_quant_eq(mapping = use_label("eq"), formula = y ~ x, color = "blue",
                 quantiles = 0.05) +
   stat_quant_line(formula = x ~ y, color = "red", quantiles = 0.95) +
-  stat_quant_eq(aes(label = after_stat(eq.label)), formula = x ~ y, color = "red", 
+  stat_quant_eq(mapping = use_label("eq"), formula = x ~ y, color = "red", 
                 quantiles = 0.95, label.y = 0.9)
 
 ## -----------------------------------------------------------------------------
@@ -421,7 +441,7 @@ ggplot(my.data.outlier, aes(x, y)) +
   scale_color_gradient(low = "red", high = "blue", limits = c(0, 1)) +
   geom_point()
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 # formula <- y ~ poly(x, 3, raw = TRUE)
 # broom::augment does not handle poly() correctly!
 formula <- y ~ x + I(x^2) + I(x^3)
@@ -432,12 +452,11 @@ ggplot(my.data, aes(x, y, colour = group)) +
                   method.args = list(formula = formula),
                   label.x = "right",
                   label.y = "bottom",
-                  aes(label = paste("italic(P)*\"-value = \"*", 
-                                    signif(after_stat(p.value), digits = 4),
-                                    sep = "")),
+                  aes(label = sprintf("italic(P)*\"-value = \"*%.3g", 
+                                      after_stat(p.value))),
                   parse = TRUE)
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 micmen.formula <- y ~ SSmicmen(x, Vm, K) 
 ggplot(Puromycin, aes(conc, rate, colour = state)) +
   geom_point() +
@@ -451,7 +470,95 @@ ggplot(Puromycin, aes(conc, rate, colour = state)) +
                                     sep = "")),
                   label.x = "centre", label.y = "bottom")
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
+formula <- y ~ x + I(x^2) + I(x^3)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  geom_smooth(method = "lm", formula = formula) +
+  stat_fit_tb(method = "lm",
+              method.args = list(formula = formula),
+              tb.vars = c(Parameter = "term", 
+                          Estimate = "estimate", 
+                          "s.e." = "std.error", 
+                          "italic(t)" = "statistic", 
+                          "italic(P)" = "p.value"),
+              label.y = "top", label.x = "left",
+              parse = TRUE)
+
+## ---- eval=eval_broom---------------------------------------------------------
+formula <- y ~ x + I(x^2) + I(x^3)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  geom_smooth(method = "lm", formula = formula) +
+  stat_fit_tb(method = "lm",
+              method.args = list(formula = formula),
+              tb.type = "fit.anova",
+              tb.vars = c(Effect = "term", 
+                          df = "df",
+                          "italic(F)" = "statistic", 
+                          "italic(P)" = "p.value"),
+              tb.params = c(x = 1, "x^2" = 2, "x^3" = 3, Resid = 4),
+              label.y = "top", label.x = "left",
+              parse = TRUE)
+
+## ---- eval=eval_broom---------------------------------------------------------
+formula <- y ~ x + I(x^2) + I(x^3)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  geom_smooth(method = "lm", formula = formula) +
+  stat_fit_tb(method = "lm",
+              method.args = list(formula = formula),
+              tb.type = "fit.coefs", parse = TRUE,
+              label.y = "center", label.x = "left")
+
+## ---- eval=eval_broom---------------------------------------------------------
+micmen.formula <- y ~ SSmicmen(x, Vm, K)
+ggplot(Puromycin, aes(conc, rate, colour = state)) +
+  facet_wrap(~state) +
+  geom_point() +
+  geom_smooth(method = "nls",
+              formula = micmen.formula,
+              se = FALSE) +
+  stat_fit_tb(method = "nls",
+              method.args = list(formula = micmen.formula),
+              tb.type = "fit.coefs",
+              label.x = 0.9,
+              label.y = c(0.75, 0.2)) +
+  theme(legend.position = "none") +
+  labs(x = "C", y = "V")
+
+## ---- eval=eval_broom---------------------------------------------------------
+ggplot(chickwts, aes(factor(feed), weight)) +
+  stat_summary(fun.data = "mean_se") +
+  stat_fit_tb(tb.type = "fit.anova",
+              label.x = "center",
+              label.y = "bottom") +
+  expand_limits(y = 0)
+
+## ---- eval=eval_broom---------------------------------------------------------
+ggplot(chickwts, aes(factor(feed), weight)) +
+  stat_summary(fun.data = "mean_se") +
+  stat_fit_tb(tb.type = "fit.anova", label.x = "left", size = 3) +
+  scale_x_discrete(expand = expansion(mult = c(0.2, 0.5))) +
+  coord_flip()
+
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
+ggplot(chickwts, aes(factor(feed), weight)) +
+  stat_summary(fun.data = "mean_se") +
+  stat_fit_tb(tb.type = "fit.anova",
+              angle = 90, size = 3,
+              label.x = "right", label.y = "center",
+              hjust = 0.5, vjust = 0,
+              tb.vars = c(Effect = "term", 
+                          "df",
+                          "M.S." = "meansq", 
+                          "italic(F)" = "statistic", 
+                          "italic(P)" = "p.value"),
+              parse = TRUE) +
+  scale_x_discrete(expand = expansion(mult = c(0.1, 0.35))) +
+  expand_limits(y = 0)
+
+## ---- eval=eval_broom---------------------------------------------------------
 micmen.formula <- y ~ SSmicmen(x, Vm, K) 
 ggplot(Puromycin, aes(conc, rate, colour = state)) +
   geom_point() +
@@ -469,7 +576,7 @@ ggplot(Puromycin, aes(conc, rate, colour = state)) +
                                   sep = "")),
                 parse = TRUE)
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 micmen.formula <- y ~ SSmicmen(x, Vm, K) 
 ggplot(Puromycin, aes(conc, rate, colour = state)) +
   geom_point() +
@@ -488,7 +595,7 @@ ggplot(Puromycin, aes(conc, rate, colour = state)) +
                 parse = TRUE) +
   labs(x = "C", y = "V")
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 stat_micmen_eq <- function(vstep = 0.12,
                            size = 3,
                            ...) {
@@ -503,7 +610,7 @@ stat_micmen_eq <- function(vstep = 0.12,
                 ...)
 }
 
-## ---- eval=eval_flag----------------------------------------------------------
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
 micmen.formula <- y ~ SSmicmen(x, Vm, K) 
 ggplot(Puromycin, aes(conc, rate, colour = state)) +
   geom_point() +
@@ -514,7 +621,7 @@ ggplot(Puromycin, aes(conc, rate, colour = state)) +
                 label.y = "bottom") +
   labs(x = "C", y = "V")
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 my_formula <- y ~ x
 
 ggplot(mpg, aes(displ, 1 / hwy)) +
@@ -529,7 +636,7 @@ ggplot(mpg, aes(displ, 1 / hwy)) +
                                               after_stat(x_p.value))),
                 parse = TRUE)
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 stat_rq_eqn <- 
   function(formula = y ~ x, 
            tau = 0.5,
@@ -549,101 +656,13 @@ stat_rq_eqn <-
                   ...)
   }
 
-## ---- eval=eval_flag----------------------------------------------------------
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
 ggplot(mpg, aes(displ, 1 / hwy)) +
   geom_point() +
   geom_quantile(quantiles = 0.5, formula = my_formula) +
   stat_rq_eqn(tau = 0.5, formula = my_formula)
 
-## -----------------------------------------------------------------------------
-formula <- y ~ x + I(x^2) + I(x^3)
-ggplot(my.data, aes(x, y)) +
-  geom_point() +
-  geom_smooth(method = "lm", formula = formula) +
-  stat_fit_tb(method = "lm",
-              method.args = list(formula = formula),
-              tb.vars = c(Parameter = "term", 
-                          Estimate = "estimate", 
-                          "s.e." = "std.error", 
-                          "italic(t)" = "statistic", 
-                          "italic(P)" = "p.value"),
-              label.y = "top", label.x = "left",
-              parse = TRUE)
-
-## -----------------------------------------------------------------------------
-formula <- y ~ x + I(x^2) + I(x^3)
-ggplot(my.data, aes(x, y)) +
-  geom_point() +
-  geom_smooth(method = "lm", formula = formula) +
-  stat_fit_tb(method = "lm",
-              method.args = list(formula = formula),
-              tb.type = "fit.anova",
-              tb.vars = c(Effect = "term", 
-                          df = "df",
-                          "italic(F)" = "statistic", 
-                          "italic(P)" = "p.value"),
-              tb.params = c(x = 1, "x^2" = 2, "x^3" = 3, Resid = 4),
-              label.y = "top", label.x = "left",
-              parse = TRUE)
-
-## -----------------------------------------------------------------------------
-formula <- y ~ x + I(x^2) + I(x^3)
-ggplot(my.data, aes(x, y)) +
-  geom_point() +
-  geom_smooth(method = "lm", formula = formula) +
-  stat_fit_tb(method = "lm",
-              method.args = list(formula = formula),
-              tb.type = "fit.coefs", parse = TRUE,
-              label.y = "center", label.x = "left")
-
-## -----------------------------------------------------------------------------
-micmen.formula <- y ~ SSmicmen(x, Vm, K)
-ggplot(Puromycin, aes(conc, rate, colour = state)) +
-  facet_wrap(~state) +
-  geom_point() +
-  geom_smooth(method = "nls",
-              formula = micmen.formula,
-              se = FALSE) +
-  stat_fit_tb(method = "nls",
-              method.args = list(formula = micmen.formula),
-              tb.type = "fit.coefs",
-              label.x = 0.9,
-              label.y = c(0.75, 0.2)) +
-  theme(legend.position = "none") +
-  labs(x = "C", y = "V")
-
-## -----------------------------------------------------------------------------
-ggplot(chickwts, aes(factor(feed), weight)) +
-  stat_summary(fun.data = "mean_se") +
-  stat_fit_tb(tb.type = "fit.anova",
-              label.x = "center",
-              label.y = "bottom") +
-  expand_limits(y = 0)
-
-## -----------------------------------------------------------------------------
-ggplot(chickwts, aes(factor(feed), weight)) +
-  stat_summary(fun.data = "mean_se") +
-  stat_fit_tb(tb.type = "fit.anova", label.x = "left", size = 3) +
-  scale_x_discrete(expand = expansion(mult = c(0.2, 0.5))) +
-  coord_flip()
-
-## ---- eval=eval_flag----------------------------------------------------------
-ggplot(chickwts, aes(factor(feed), weight)) +
-  stat_summary(fun.data = "mean_se") +
-  stat_fit_tb(tb.type = "fit.anova",
-              angle = 90, size = 3,
-              label.x = "right", label.y = "center",
-              hjust = 0.5, vjust = 0,
-              tb.vars = c(Effect = "term", 
-                          "df",
-                          "M.S." = "meansq", 
-                          "italic(F)" = "statistic", 
-                          "italic(P)" = "p.value"),
-              parse = TRUE) +
-  scale_x_discrete(expand = expansion(mult = c(0.1, 0.35))) +
-  expand_limits(y = 0)
-
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 # formula <- y ~ poly(x, 3, raw = TRUE)
 # broom::augment does not handle poly correctly!
 formula <- y ~ x + I(x^2) + I(x^3)
@@ -652,14 +671,14 @@ ggplot(my.data, aes(x, y)) +
   stat_fit_augment(method = "lm",
                    method.args = list(formula = formula))
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3)
 ggplot(my.data, aes(x, y, colour = group)) +
   geom_point() +
   stat_fit_augment(method = "lm", 
                    method.args = list(formula = formula))
 
-## ---- eval=eval_flag----------------------------------------------------------
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3)
 ggplot(my.data, aes(x, y)) +
   stat_fit_augment(method = "lm",
@@ -667,7 +686,7 @@ ggplot(my.data, aes(x, y)) +
                    geom = "point",
                    y.out = ".resid")
 
-## -----------------------------------------------------------------------------
+## ---- eval=eval_broom---------------------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3)
 ggplot(my.data, aes(x, y, colour = group)) +
   stat_fit_augment(method = "lm",
@@ -675,7 +694,7 @@ ggplot(my.data, aes(x, y, colour = group)) +
                    geom = "point",
                    y.out = ".std.resid")
 
-## ---- eval=eval_flag----------------------------------------------------------
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
 args <- list(formula = y ~ k * e ^ x,
              start = list(k = 1, e = 2))
 ggplot(mtcars, aes(wt, mpg)) +
@@ -683,7 +702,7 @@ ggplot(mtcars, aes(wt, mpg)) +
   stat_fit_augment(method = "nls",
                    method.args = args)
 
-## ---- eval=eval_flag----------------------------------------------------------
+## ---- eval=(eval_flag && eval_broom)------------------------------------------
 args <- list(formula = y ~ k * e ^ x,
              start = list(k = 1, e = 2))
 ggplot(mtcars, aes(wt, mpg)) +
@@ -703,40 +722,69 @@ ggplot(Orange, aes(age, circumference, colour = Tree)) +
                    method.args = args,
                    augment.args = list(data = quote(data)))
 
+## ---- eval=(eval_broom && eval_gginnards)-------------------------------------
+# formula <- y ~ poly(x, 3, raw = TRUE)
+# broom::augment does not handle poly() correctly!
+formula <- y ~ x + I(x^2) + I(x^3)
+ggplot(my.data, aes(x, y, colour = group)) +
+  geom_point() +
+  geom_smooth(method = "lm", formula = formula) +
+  stat_fit_glance(geom = "debug",
+                  method = "lm", 
+                  method.args = list(formula = formula),
+                  label.x = "right",
+                  label.y = "bottom",
+                  aes(label = sprintf("italic(P)*\"-value = \"*%.3g", 
+                                      after_stat(p.value))),
+                  parse = TRUE)
+
+## ---- eval=(eval_broom && eval_gginnards)-------------------------------------
+formula <- y ~ x + I(x^2) + I(x^3)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  geom_smooth(method = "lm", formula = formula) +
+  stat_fit_tb(geom = "debug",
+              summary.fun = str,
+              method = "lm",
+              method.args = list(formula = formula),
+              tb.vars = c(Parameter = "term", 
+                          Estimate = "estimate", 
+                          "s.e." = "std.error", 
+                          "italic(t)" = "statistic", 
+                          "italic(P)" = "p.value"),
+              label.y = "top", label.x = "left",
+              parse = TRUE)
+
 ## -----------------------------------------------------------------------------
 head(volcano_example.df) 
 
 ## -----------------------------------------------------------------------------
-volcano_example.df %>%
-  mutate(., outcome.fct = outcome2factor(outcome)) %>%
-  ggplot(., aes(logFC, PValue, colour = outcome.fct)) +
+ggplot(volcano_example.df, 
+       aes(logFC, PValue, colour = outcome2factor(outcome))) +
   geom_point() +
   scale_x_logFC(name = "Transcript abundance%unit") +
   scale_y_Pvalue() +
   scale_colour_outcome() +
-  stat_quadrant_counts(data = . %>% filter(outcome != 0))
+  stat_quadrant_counts(data = function(x) {subset(x, outcome != 0)})
 
 ## -----------------------------------------------------------------------------
-volcano_example.df %>%
-  mutate(., outcome.fct = outcome2factor(outcome, n.levels = 2)) %>%
-  ggplot(., aes(logFC, PValue, colour = outcome.fct)) +
+ggplot(volcano_example.df, 
+       aes(logFC, PValue, colour = outcome2factor(outcome, n.levels = 2))) +
   geom_point() +
   scale_x_logFC(name = "Transcript abundance%unit") +
   scale_y_Pvalue() +
   scale_colour_outcome() +
-  stat_quadrant_counts(data = . %>% filter(outcome != 0))
+  stat_quadrant_counts(data = function(x) {subset(x, outcome != 0)})
 
 ## -----------------------------------------------------------------------------
 head(quadrant_example.df)
 
 ## -----------------------------------------------------------------------------
-quadrant_example.df %>%
-  mutate(.,
-         outcome.x.fct = outcome2factor(outcome.x),
-         outcome.y.fct = outcome2factor(outcome.y),
-         outcome.xy.fct = xy_outcomes2factor(outcome.x, outcome.y)) %>%
-         filter(outcome.xy.fct != "none") %>%
-  ggplot(., aes(logFC.x, logFC.y, colour = outcome.x.fct, fill = outcome.y.fct)) +
+  ggplot(subset(quadrant_example.df, 
+                xy_outcomes2factor(outcome.x, outcome.y) != "none"),
+         aes(logFC.x, logFC.y, 
+             colour = outcome2factor(outcome.x), 
+             fill = outcome2factor(outcome.y))) +
   geom_quadrant_lines(linetype = "dotted") +
   stat_quadrant_counts(size = 3, colour = "white") +
   geom_point(shape = "circle filled") +
@@ -762,13 +810,13 @@ all_quadrant_lines <- function(...) {
     geom_hline(data =  data.frame(outcome.xy.fct = factor(c("xy", "x", "y", "none"),
                                                           levels = c("xy", "x", "y", "none")),
                                   yintercept = c(0, NA, 0, NA)),
-               aes_(yintercept = ~yintercept),
+               aes(yintercept = yintercept),
                na.rm = TRUE,
                ...),
     geom_vline(data =  data.frame(outcome.xy.fct = factor(c("xy", "x", "y", "none"),
                                                           levels = c("xy", "x", "y", "none")),
                                   xintercept = c(0, 0, NA, NA)),
-               aes_(xintercept = ~xintercept),
+               aes(xintercept = xintercept),
                na.rm = TRUE,
                ...)
   )
